<?php
/**
 * Load Hooks
 *
 * @package Greenturtle_Mag
 */

/******
    Doctype hook of the theme
******/
if ( ! function_exists( 'greenturtle_mag_doctype_action' ) ) :
    /**
     * Doctype declaration of the theme.
     *
     * @since 1.0.0
     */
    function greenturtle_mag_doctype_action() {
    ?>
    <!DOCTYPE html> 
    <html <?php language_attributes(); ?>>
    <?php
    }
endif;

add_action( 'greenturtle_mag_doctype', 'greenturtle_mag_doctype_action', 10 );

/******
    Head hook of the theme
******/
if ( ! function_exists( 'greenturtle_mag_head_action' ) ) :
    /**
     * Header hook of the theme.
     *
     * @since 1.0.0
     */
    function greenturtle_mag_head_action() {
    ?>
        <meta charset="<?php bloginfo( 'charset' ); ?>">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <link rel="profile" href="http://gmpg.org/xfn/11">
        <?php wp_head(); ?>
    <?php
    }
endif;

add_action( 'greenturtle_mag_head', 'greenturtle_mag_head_action', 10 );

if ( ! function_exists( 'greenturtle_mag_skip_to_content' ) ) :
/**
 * Skip to content
 *
 * @since greenturtle_mag 1.0.0
 *

 *
 */
function greenturtle_mag_skip_to_content() {
    ?>
    <a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'greenturtle-mag' ); ?></a>
    <?php get_template_part( 'template-parts/header/header', 'image' ); ?>
<?php
}
endif;
add_action( 'greenturtle_mag_action_before_header', 'greenturtle_mag_skip_to_content', 10 );


if ( ! function_exists( 'greenturtle_mag_header' ) ) :
/**
 * Main header
 *
 * @since greenturtle_mag 1.0.0
 *
 * @param null
 * @return null
 *
 */
function greenturtle_mag_header() {
    ?>
    <?php 
        $enable_top = esc_attr(get_theme_mod('top_disable','1'));
        if($enable_top==1){
     ?>
    <div class="container top-header-wrapper">
            <div class="col-xs-12 col-sm-12 col-md-12 top-header-right">
            <?php if (has_nav_menu('top-menu' )) { ?>
                    <div class="col-md-5 col-xs-12 col-sm-5 menu-top-nav-container">
                        <div class="menu-top-menu-container">
                             <?php
                               wp_nav_menu( array( 
                                    'theme_location' => 'top-menu', 
                                    'link_before' => '<span>',
                                    'link_after'=>'</span>' , 
                                    'menu_id' => 'top-menu',
                                    'fallback_cb' => false,
                                ) );
                            ?>
                        </div>                
                    </div>
                <?php } ?>
                  <div class="timer col-md-3 col-xs-12 col-sm-3">
                        <?php echo date_i18n( get_option( 'date_format' ), strtotime( 'l, M j, Y' ) ); ?>          
                    </div>
                   
                    <div class="social-widget greenturtle-social-section social-icon-only bottom-tooltip col-md-4 col-xs-12 col-sm-4">
                    <div class="menu-social-icon-container"><ul class="">
                    <?php if ( esc_url(get_theme_mod( 'profile_facebook','' )) ) : ?>
                        <li class="social-items"><a target="_blank" href="<?php echo  esc_url(get_theme_mod( 'profile_facebook','' )); ?>"></a>
                        </li>
                    <?php endif;?>
                    <?php if ( esc_url(get_theme_mod( 'profile_twitter','' )) ) : ?>
                        <li class="social-items"><a target="_blank" href="<?php echo  esc_url(get_theme_mod( 'profile_twitter','' )); ?>"></a>
                        </li>
                    <?php endif;?>

                    <?php if ( esc_url(get_theme_mod( 'profile_linkedin','' )) ) : ?>
                        <li class="social-items"><a target="_blank" href="<?php echo  esc_url(get_theme_mod( 'profile_linkedin','' )); ?>"></a>
                        </li>
                    <?php endif;?>
                    <?php if ( esc_url(get_theme_mod( 'profile_pinterest','' )) ) : ?>
                        <li class="social-items"><a target="_blank" href="<?php echo esc_url(get_theme_mod( 'profile_pinterest','' )); ?>"></a>
                        </li>
                    <?php endif;?>
                    <?php if ( esc_url(get_theme_mod( 'profile_instagram','' )) ) : ?>
                        <li class="social-items"><a target="_blank" href="<?php echo esc_url(get_theme_mod( 'profile_instagram','' )); ?>"></a>
                        </li>
                    <?php endif;?>
                    <?php if ( esc_url(get_theme_mod( 'profile_tumblr','' )) ) : ?>
                        <li class="social-items"><a target="_blank" href="<?php echo esc_url(get_theme_mod( 'profile_tumblr','' )); ?>"></a>
                        </li>
                    <?php endif;?>
                    <?php if ( esc_url(get_theme_mod( 'profile_youtube','' )) ) : ?>
                        <li class="social-items"><a target="_blank" href="<?php echo esc_url(get_theme_mod( 'profile_youtube','' )); ?>"></a>
                        </li>
                    <?php endif;?>
                        
                    </ul></div>                
                </div>

               
                    </div>
                </div>
        <?php } ?>
    <header  class="wrapper wrap-head site-header">
        <div class="wrapper wrapper-site-identity">
            <div class="container">
                <div class="row">
                    <div class="col-xs-12 col-sm-12 col-md-4">
                        <div class="site-branding">
                            <?php
                                if ( is_front_page() && is_home() ) : ?>
                                    <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
                                <?php else : ?>
                                    <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
                                <?php
                                endif;

                                $description = get_bloginfo( 'description', 'display' );
                                if ( $description || is_customize_preview() ) : ?>
                                    <p class="site-description"><?php echo esc_html($description); /* WPCS: xss ok. */ ?></p>
                                <?php
                                endif; ?>
                            <?php the_custom_logo(); ?>
                        </div><!-- .site-branding -->
                    </div>
                  
                        <div class="col-xs-12 col-sm-12 col-md-8">
                            <div class="ads-section header-right">
                               <?php
                                    if( is_active_sidebar( 'sidebar-top' ) ) :
                                        dynamic_sidebar( 'sidebar-top' );
                                    endif;
                                ?>
                            </div>
                        </div>
                   
                </div>
            </div>
        </div>
    </header><!-- #masthead -->

<?php 
}
endif;
add_action( 'greenturtle_mag_action_header', 'greenturtle_mag_header', 10 );



if ( ! function_exists( 'greenturtle_mag_navigation_page_start' ) ) :
/**
 * Navigatiion
 *
 * @since greenturtle_mag 1.0.0
 *
 * @param null
 * @return null
 *
 */
function greenturtle_mag_navigation_page_start() {

    ?>
      <nav class="wrapper wrap-nav">
            <div class="container">
                <div class="wrap-inner">
                    <div class="sec-menu">
                        <nav id="sec-site-navigation" class="main-navigation sec-main-navigation"  aria-label="secondary-menu">
                         <?php 
                            $enable_icon = esc_attr(get_theme_mod('home_button_enable','enable'));
                            if($enable_icon=="enable"){
                         ?>
                            <div class="np-home-icon">
                                <a href="<?php echo esc_url(home_url()); ?>" rel="home"> <i class="fa fa-home"> </i> </a>
                            </div>
                        <?php } ?>
                              <?php wp_nav_menu( array( 
                                'theme_location' => 'primary-menu', 
                                'menu_class'     => 'primary-menu',
                                'container'      => 'div',
                                'container_class'=> 'primary-menu',
                                'items_wrap'     => '<ul id="%1$s">%3$s</ul>',
                                'walker'         => '',
                                'fallback_cb'    => 'wp_page_menu',
                                ) ); ?>     
                        </nav><!-- #site-navigation -->
                            <div class="nav-holder">
                                <button id="sec-menu-toggle" class="menu-toggle" aria-controls="secondary-menu" aria-expanded="false"><span class="fa fa-bars"></span></button>
                                <div id="sec-site-header-menu" class="site-header-menu">
                                    <div class="container">
                                        <div class="row">
                                            <div class="col-xs-12 col-sm-12 col-md-12">
                                                <button id="mobile-menu-toggle-close" class="menu-toggle" aria-controls="secondary-menu"><span class="fa fa-close fa-2x"></span></button>
                                            </div>
                                            <div class="col-xs-12 col-sm-12 col-md-12">
                                                <nav id="sec-site-navigation-mobile" class="main-navigation sec-main-navigation"  aria-label="secondary-menu">
                                                
                                                <?php wp_nav_menu( array( 
                                                        'theme_location' => 'primary-menu', 
                                                        'menu_class'     => 'primary-menu',
                                                        'container'      => 'div',
                                                        'container_class'=> 'primary-menu',
                                                        'items_wrap'     => '<ul id="%1$s">%3$s</ul>',
                                                        'walker'         => '',
                                                        'fallback_cb'    => 'wp_page_menu',
                                                 ) ); ?>                                  
                                                </nav><!-- #site-navigation -->
                                            </div>
                                        </div>
                                    </div>
                                </div><!-- site-header-menu -->
                            </div>
                        </div> 
                <?php 
                    $serach_breaking = esc_attr(get_theme_mod('search_disable',1));
                    if($serach_breaking==1){
                 ?>
                        <div class="nav-buttons col-md-1">                        

                            <div class="button-list">
                                <div class="search-holder">
                                    <a class="button-search button-outline" href="#">
                                        <i class="fa fa-search"></i>
                                    </a>                                
                                </div>
                            </div>                            
                        </div> 
                <?php }?>                   

                    </div>
                <?php 
                    $serach_breaking = esc_attr(get_theme_mod('search_disable',1));
                    if($serach_breaking==1){
                 ?>
                    <div class="search-form-nav" id="top-search">
                      <?php echo  get_search_form(); ?>       
                    </div>

                    <?php }?>
                    </div>
                </nav>
                <?php 
                    $enable_breaking = esc_attr(get_theme_mod('breaking_disable',1));
                    if($enable_breaking==1){
                 ?>
                <header class="wrapper top-header">
                    <div class="container">
                        <div class="wrap-inner">
                            <div class="row">
                                <div class="col-xs-12 col-sm-11 col-md-11 top-header-left">
                                    <div class="noticebar">
                                        <span class="notice-title"><?php echo esc_attr(get_theme_mod('breaking_news_title',__( 'Breaking News', 'greenturtle-mag' ))); ?></span>
                                        <div class="ticker">
                                            <div id="cycle-slideshow-ticker" class="cycle-slideshow"
                                            data-cycle-log="false"
                                            data-cycle-swipe=true
                                            data-cycle-timeout=5000
                                            data-cycle-fx=scrollVert
                                            data-cycle-speed=1000
                                            data-cycle-carousel-fluid=true
                                            data-cycle-carousel-visible=5
                                            data-cycle-pause-on-hover=true
                                            data-cycle-auto-height=container
                                            data-cycle-prev=#slide-prev-notice
                                            data-cycle-next=#slide-next-notice 
                                            data-cycle-slides="> div">
                        <?php
                            $breaking_news_catId = esc_attr(get_theme_mod( 'breaking_news_category',1 ));
                            $breaking_news_link = get_category_link( $breaking_news_catId );
                            $breaking_news_cat_name = get_category( $breaking_news_catId );
                            $args = array(
                                'post_type' => 'post',
                                'post_status' => 'publish',
                                'paged' => 1,
                                'cat' => $breaking_news_catId,
                                'orderby' => 'ID',
                                'order' => 'DESC'
                            );
                            $loop = new WP_Query($args);
                            if ( $loop->have_posts() ) :
                                while ($loop->have_posts()) : $loop->the_post(); 
                            ?>

                                        <div class="slide-item">
                                            <a href="<?php the_permalink(); ?>">
                                                <span class="notice-content"><?php the_title(); ?></span>
                                            </a>
                                        </div>
                                 <?php 
                                        endwhile;
                                        wp_reset_postdata();
                                    endif;
                                ?>        

                                    </div>
                                    <div class="cycle-pager" id="slide-pager"></div>
                                </div>
                            </div>                            

                            </div>   
                            <div class="controls col-md-1 hidden-xs">
                                <a href="#" id="slide-prev-notice"><i class="fa fa-caret-left"></i></a>
                                <a href="#" id="slide-next-notice"><i class="fa fa-caret-right"></i></a>
                            </div>                   
                        </div>
                    </div>
                </div>
            </header>
            <?php } ?>
    <section class="wrapper">
        <div id="content" class="site-content">
    <?php
}
endif;
add_action( 'greenturtle_mag_action_nav_page_start', 'greenturtle_mag_navigation_page_start', 10 );





if ( ! function_exists( 'greenturtle_mag_before_footer_widget' ) ) :
/**
 * 
 *
 * @since greenturtle_mag 1.0.0
 *

 *
 */
function greenturtle_mag_before_footer_widget() {
    ?>
        </div>
    </section>
   <footer class="wrapper wrap-footer">
<?php
}
endif;
add_action( 'greenturtle_mag_action_before_footer_widget', 'greenturtle_mag_before_footer_widget', 10 );



if ( ! function_exists( 'greenturtle_mag_widget_before_footer' ) ) :
/**
 * 
 *
 * @since greenturtle_mag 1.0.0
 *

 *
 */
function greenturtle_mag_widget_before_footer() {
    ?>
 
         <section class="wrapper footer-widget">
            <div class="container">
                <div class="row">                    
                    <?php if( is_active_sidebar( 'footer-sidebar' ) ) : ?>
                        
                            <?php dynamic_sidebar( 'footer-sidebar' ); ?>
                        
                    <?php endif; ?>
                    
                </div>
            </div>
        </section>
   
<?php
}
endif;
add_action( 'greenturtle_mag_action_widget_before_footer', 'greenturtle_mag_widget_before_footer', 10 );



if ( ! function_exists( 'greenturtle_mag_footer' ) ) :
/**
 * 
 *
 * @since greenturtle_mag 1.0.0
 *

 *
 */
function greenturtle_mag_footer() {
    ?>
    <!-- footer site info -->
<section id="colophon" class="wrapper site-footer" >
    <div class="container">
        <div class="row">
            <div class="xs-12 col-sm-6 col-md-6">
                <div class="site-info">
                <?php echo esc_attr(get_theme_mod('copyright_textbox')); ?>

                  </div><!-- .site-info -->
                </div>
                <div class="xs-12 col-sm-6 col-md-6">
                    <div class="footer-menu">
                        <nav id="footer-site-navigation" class="footer-main-navigation" role="navigation" aria-label="footer-menu">
                            <div class="menu-footer-menu-container"> 
                            <?php
                               wp_nav_menu( array( 
                                    'theme_location' => 'footer-menu', 
                                    'link_before' => '<span>',
                                    'link_after'=>'</span>' , 
                                    'menu_id' => 'footer-menu',
                                    'fallback_cb' => false,
                                ) );
                            ?>
                                
                            </div> 
                        </nav><!-- #site-navigation --> 
                        </div>
                    </div>
                </div>
            </div>
        </section><!-- #colophon -->    
   
<?php
}
endif;
add_action( 'greenturtle_mag_action_footer', 'greenturtle_mag_footer', 10 );


if ( ! function_exists( 'greenturtle_mag_after_footer' ) ) :
/**
 * 
 *
 * @since greenturtle_mag 1.0.0
 *

 *
 */
function greenturtle_mag_after_footer() {
    ?>
   </footer><!-- #colophon -->
<?php
}
endif;
add_action( 'greenturtle_mag_action_after_footer', 'greenturtle_mag_after_footer', 10 );