<?php
/**
 * Custom Widgets
 *
 * @since 1.0.0
 */

if( ! function_exists( 'gtl_mag_advertisement' ) ) :
	/**
     * Register and load widgets.
     *
     * @since 1.0.0
     */
	function gtl_mag_advertisement() {

		/*
			Advertisement  Widget Register
		*/
		register_widget( 'gtl_mag_365x250_advertisement' );

		register_widget( 'gtl_mag_728x90_advertisement' );

		register_widget( 'gtl_mag_760x90_advertisement' );

	}
endif;
add_action( 'widgets_init', 'gtl_mag_advertisement' );

if( ! class_exists( 'gtl_mag_365x250_advertisement' ) ) :
	/**
	 * Main Highlight
	 *
	 * @since 1.0.0
	 */
class gtl_mag_365x250_advertisement extends WP_Widget {

	function __construct() {
		$widget_ops  = array( 'classname' => '', 'description' => __( 'Add your 365x250 Advertisement here(Recommended for Homepage sidebar and Sidebar)', 'greenturtle-mag' ) );
		$control_ops = array( 'width' => 200, 'height' => 250 );
		parent::__construct( 'gtl_mag_365x250_advertisement', esc_html__( 'GTL: 365x250 Advertisement  ', 'greenturtle-mag' ), $widget_ops );
	}

	function form( $instance ) {
		$instance = wp_parse_args( ( array ) $instance, array( 'title' => '', '365x250_image_url' => '', '365x250_image_link' => '' ) );
		$title    = esc_attr( $instance[ 'title' ] );

		$image_link = '365x250_image_link';
		$image_url  = '365x250_image_url';

		$instance[ $image_link ] = esc_url( $instance[ $image_link ] );
		$instance[ $image_url ]  = esc_url( $instance[ $image_url ] );
		?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'greenturtle-mag' ); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>"/>
		</p>
		<label><?php _e( 'Add your Advertisement 365x250 Images Here', 'greenturtle-mag' ); ?></label>
		<p>
			<label for="<?php echo $this->get_field_id( $image_link ); ?>"> <?php _e( 'Advertisement Image Link ', 'greenturtle-mag' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( $image_link ); ?>" name="<?php echo $this->get_field_name( $image_link ); ?>" value="<?php echo $instance[ $image_link ]; ?>"/>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( $image_url ); ?>"> <?php _e( 'Advertisement Image ', 'greenturtle-mag' ); ?></label>
		<div class="media-uploader" id="<?php echo $this->get_field_id( $image_url ); ?>">
			<div class="custom_media_preview">
				<?php if ( $instance[ $image_url ] != '' ) : ?>
					<img class="custom_media_preview_default" src="<?php echo esc_url( $instance[ $image_url ] ); ?>" style="max-width:100%;"/>
				<?php endif; ?>
			</div>
			<input type="text" class="widefat custom_media_input" id="<?php echo $this->get_field_id( $image_url ); ?>" name="<?php echo $this->get_field_name( $image_url ); ?>" value="<?php echo esc_url( $instance[ $image_url ] ); ?>" style="margin-top:5px;"/>
			<button class="custom_media_upload button button-secondary button-large" id="<?php echo $this->get_field_id( $image_url ); ?>" data-choose="<?php esc_attr_e( 'Choose an image', 'greenturtle-mag' ); ?>" data-update="<?php esc_attr_e( 'Use image', 'greenturtle-mag' ); ?>" style="width:100%;margin-top:6px;margin-right:30px;"><?php esc_html_e( 'Select an Image', 'greenturtle-mag' ); ?></button>
		</div>
		</p>

		<?php
	}

	function update( $new_instance, $old_instance ) {
		$instance            = $old_instance;
		$instance[ 'title' ] = sanitize_text_field( $new_instance[ 'title' ] );

		$image_link = '365x250_image_link';
		$image_url  = '365x250_image_url';

		$instance[ $image_link ] = esc_url_raw( $new_instance[ $image_link ] );
		$instance[ $image_url ]  = esc_url_raw( $new_instance[ $image_url ] );

		return $instance;
	}

	function widget( $args, $instance ) {
		
		$title = isset( $instance[ 'title' ] ) ? $instance[ 'title' ] : '';

		$image_link = '365x250_image_link';
		$image_url  = '365x250_image_url';

		$image_link = isset( $instance[ $image_link ] ) ? $instance[ $image_link ] : '';
		$image_url  = isset( $instance[ $image_url ] ) ? $instance[ $image_url ] : '';

		
		?>

		<div class="advertisement_365x250">
			<?php if ( ! empty( $title ) ) { ?>
				<div class="widget advertisement-title ">
					<h2 class="widget-title"><?php echo   esc_html( $title ); ?></h2>
				
				<?php
			}
			$output = '';
			if ( ! empty( $image_url ) ) {
				$image_id  = attachment_url_to_postid( $image_url );
				$image_alt = get_post_meta( $image_id, '_wp_attachment_image_alt', true );
				$output    .= '<div class="advertisement-content">';
				if ( ! empty( $image_link ) ) {
					$output .= '<a href="' . $image_link . '" class="single_ad_365x250" target="_blank" rel="nofollow">
                                    <img src="' . $image_url . '" width="365" height="250" alt="' . $image_alt . '">
                           </a>';
				} else {
					$output .= '<img src="' . $image_url . '" width="365" height="250" alt="' . $image_alt . '">';
				}
				$output .= '</div>';
				echo $output;
			}
			?>
			</div>
		</div>
		<?php
	}

}
endif;



if( ! class_exists( 'gtl_mag_728x90_advertisement' ) ) :
	/**
	 * Main Highlight
	 *
	 * @since 1.0.0
	 */
class gtl_mag_728x90_advertisement extends WP_Widget {

	function __construct() {
		$widget_ops  = array( 'classname' => '', 'description' => __( 'Add your 728x90 Advertisement here(Recommended for Header Advertisement)', 'greenturtle-mag' ) );
		$control_ops = array( 'width' => 200, 'height' => 250 );
		parent::__construct( 'gtl_mag_728x90_advertisement', esc_html__( 'GTL: 728x90 Advertisement  ', 'greenturtle-mag' ), $widget_ops );
	}

	function form( $instance ) {
		$instance = wp_parse_args( ( array ) $instance, array( 'title' => '', '728x90_image_url' => '', '728x90_image_link' => '' ) );
		

		$image_link = '728x90_image_link';
		$image_url  = '728x90_image_url';

		$instance[ $image_link ] = esc_url( $instance[ $image_link ] );
		$instance[ $image_url ]  = esc_url( $instance[ $image_url ] );
		?>

		
		<label><?php _e( 'Add your Advertisement 728x90 Images Here', 'greenturtle-mag' ); ?></label>
		<p>
			<label for="<?php echo $this->get_field_id( $image_link ); ?>"> <?php _e( 'Advertisement Image Link ', 'greenturtle-mag' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( $image_link ); ?>" name="<?php echo $this->get_field_name( $image_link ); ?>" value="<?php echo $instance[ $image_link ]; ?>"/>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( $image_url ); ?>"> <?php _e( 'Advertisement Image ', 'greenturtle-mag' ); ?></label>
		<div class="media-uploader" id="<?php echo $this->get_field_id( $image_url ); ?>">
			<div class="custom_media_preview">
				<?php if ( $instance[ $image_url ] != '' ) : ?>
					<img class="custom_media_preview_default" src="<?php echo esc_url( $instance[ $image_url ] ); ?>" style="max-width:100%;"/>
				<?php endif; ?>
			</div>
			<input type="text" class="widefat custom_media_input" id="<?php echo $this->get_field_id( $image_url ); ?>" name="<?php echo $this->get_field_name( $image_url ); ?>" value="<?php echo esc_url( $instance[ $image_url ] ); ?>" style="margin-top:5px;"/>
			<button class="custom_media_upload button button-secondary button-large" id="<?php echo $this->get_field_id( $image_url ); ?>" data-choose="<?php esc_attr_e( 'Choose an image', 'greenturtle-mag' ); ?>" data-update="<?php esc_attr_e( 'Use image', 'greenturtle-mag' ); ?>" style="width:100%;margin-top:6px;margin-right:30px;"><?php esc_html_e( 'Select an Image', 'greenturtle-mag' ); ?></button>
		</div>
		</p>

		<?php
	}

	function update( $new_instance, $old_instance ) {
		$instance            = $old_instance;
		
		$image_link = '728x90_image_link';
		$image_url  = '728x90_image_url';

		$instance[ $image_link ] = esc_url_raw( $new_instance[ $image_link ] );
		$instance[ $image_url ]  = esc_url_raw( $new_instance[ $image_url ] );

		return $instance;
	}

	function widget( $args, $instance ) {		

		$image_link = '728x90_image_link';
		$image_url  = '728x90_image_url';

		$image_link = isset( $instance[ $image_link ] ) ? $instance[ $image_link ] : '';
		$image_url  = isset( $instance[ $image_url ] ) ? $instance[ $image_url ] : '';

		
		?>

		<div class="advertisement_728x90">
			<?php 
			$output = '';
			if ( ! empty( $image_url ) ) {
				$image_id  = attachment_url_to_postid( $image_url );
				$image_alt = get_post_meta( $image_id, '_wp_attachment_image_alt', true );
				$output    .= '<div class="advertisement-content">';
				if ( ! empty( $image_link ) ) {
					$output .= '<a href="' . $image_link . '" class="single_ad_728x90" target="_blank" rel="nofollow">
                                    <img src="' . $image_url . '" width="728" height="90" alt="' . $image_alt . '">
                           </a>';
				} else {
					$output .= '<img src="' . $image_url . '" width="728" height="90" alt="' . $image_alt . '">';
				}
				$output .= '</div>';
				echo $output;
			}
			?>
		</div>
		<?php	
	}
}
endif;



if( ! class_exists( 'gtl_mag_760x90_advertisement' ) ) :
	/**
	 * Main Highlight
	 *
	 * @since 1.0.0
	 */
class gtl_mag_760x90_advertisement extends WP_Widget {

	function __construct() {
		$widget_ops  = array( 'classname' => '', 'description' => __( 'Add your 760x90 Advertisement here(Recommended for Home Page Secondary)', 'greenturtle-mag' ) );
		$control_ops = array( 'width' => 200, 'height' => 250 );
		parent::__construct( 'gtl_mag_760x90_advertisement', esc_html__( 'GTL: 760x90 Advertisement  ', 'greenturtle-mag' ), $widget_ops );
	}

	function form( $instance ) {
		$instance = wp_parse_args( ( array ) $instance, array( 'title' => '', '760x90_image_url' => '', '760x90_image_link' => '' ) );
		

		$image_link = '760x90_image_link';
		$image_url  = '760x90_image_url';

		$instance[ $image_link ] = esc_url( $instance[ $image_link ] );
		$instance[ $image_url ]  = esc_url( $instance[ $image_url ] );
		?>

		
		<label><?php _e( 'Add your Advertisement 760x90 Images Here', 'greenturtle-mag' ); ?></label>
		<p>
			<label for="<?php echo $this->get_field_id( $image_link ); ?>"> <?php _e( 'Advertisement Image Link ', 'greenturtle-mag' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( $image_link ); ?>" name="<?php echo $this->get_field_name( $image_link ); ?>" value="<?php echo $instance[ $image_link ]; ?>"/>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( $image_url ); ?>"> <?php _e( 'Advertisement Image ', 'greenturtle-mag' ); ?></label>
		<div class="media-uploader" id="<?php echo $this->get_field_id( $image_url ); ?>">
			<div class="custom_media_preview">
				<?php if ( $instance[ $image_url ] != '' ) : ?>
					<img class="custom_media_preview_default" src="<?php echo esc_url( $instance[ $image_url ] ); ?>" style="max-width:100%;"/>
				<?php endif; ?>
			</div>
			<input type="text" class="widefat custom_media_input" id="<?php echo $this->get_field_id( $image_url ); ?>" name="<?php echo $this->get_field_name( $image_url ); ?>" value="<?php echo esc_url( $instance[ $image_url ] ); ?>" style="margin-top:5px;"/>
			<button class="custom_media_upload button button-secondary button-large" id="<?php echo $this->get_field_id( $image_url ); ?>" data-choose="<?php esc_attr_e( 'Choose an image', 'greenturtle-mag' ); ?>" data-update="<?php esc_attr_e( 'Use image', 'greenturtle-mag' ); ?>" style="width:100%;margin-top:6px;margin-right:30px;"><?php esc_html_e( 'Select an Image', 'greenturtle-mag' ); ?></button>
		</div>
		</p>

		<?php
	}

	function update( $new_instance, $old_instance ) {
		$instance            = $old_instance;
		
		$image_link = '760x90_image_link';
		$image_url  = '760x90_image_url';

		$instance[ $image_link ] = esc_url_raw( $new_instance[ $image_link ] );
		$instance[ $image_url ]  = esc_url_raw( $new_instance[ $image_url ] );

		return $instance;
	}

	function widget( $args, $instance ) {		

		$image_link = '760x90_image_link';
		$image_url  = '760x90_image_url';

		$image_link = isset( $instance[ $image_link ] ) ? $instance[ $image_link ] : '';
		$image_url  = isset( $instance[ $image_url ] ) ? $instance[ $image_url ] : '';

		
		?>

		<div class="advertisement_760x90">
			<?php 
			$output = '';
			if ( ! empty( $image_url ) ) {
				$image_id  = attachment_url_to_postid( $image_url );
				$image_alt = get_post_meta( $image_id, '_wp_attachment_image_alt', true );
				$output    .= '<div class="advertisement-content">';
				if ( ! empty( $image_link ) ) {
					$output .= '<a href="' . $image_link . '" class="single_ad_760x90" target="_blank" rel="nofollow">
                                    <img src="' . $image_url . '" width="760" height="90" alt="' . $image_alt . '">
                           </a>';
				} else {
					$output .= '<img src="' . $image_url . '" width="760" height="90" alt="' . $image_alt . '">';
				}
				$output .= '</div>';
				echo $output;
			}
			?>
		</div>
		<?php	
	}
}
endif;